%% This code was used to perform balance of flows analysis in the article: 
%%"Analysis of the propionate metabolism in Bacillus subtilis during 3-indolacetic production"

run('initCobraToolbox.m'); % Starts the CobraToolbox necessary for flow balance analysis

model= xls2model('ibsu1.xlsx'); % This line of code allows you to load the metabolic model at the genomic scale in excel format [.xlsx]
                                % and it is saved in the model variable
model=readCbModel('ibsu1.mat'); % % This line of code allows you to load the metabolic model at the genomic scale in the format [.mat]
                                % and it is saved in the model variable

%% The simulation conditions are shown below depending on the experimental restrictions obtained 
% and the scenarios of interest where the flow balance analysis is carried out in each case. 
% The results obtained are represented in a metabolic map for better visualization and analysis.

% CASE 1 Bioreactor Kinetics 1 /Glucose as Source of C/ 
% Growth phase/ 
% Maximize Mu_ Biomass Exponential

%model1=changeRxnBounds(model1,'R_bio00006', 0.16,'b');
model1=changeRxnBounds(model,'R_Ex_Glc_e',-2.15,'b'); % 
model1=changeRxnBounds(model1,'R_Ex_TYR_e',0,'b');
model1=changeRxnBounds(model1,'R_Ex_Chorismate_e',0,'b');
model1=changeRxnBounds(model1,'R_Ex_TRP_e',0,'b');
%%model1=changeRxnBounds(model1,'R_EX_Propionate_e',-5,'b');
%model1=changeObjective(model1,'AIA_extracellular');

solution1=optimizeCbModel(model1)
fluxData=[solution1.v];
nonzeroflag=1;
exflag=1;
printFluxVector (model1, fluxData,nonzeroflag, exflag);

%% CASE 2 Bioreactor Kinetics 2 /Glucose as Source of C/  
% Stationary phase of growth/ 
% Maximizing AIA with qs, mu, and qtrp est as experimental constraints

model2=changeRxnBounds(model,'R_bio00006', 0.07,'b');
model2=changeRxnBounds(model2,'R_Ex_Glc_e',-1.2,'b');
%model2=changeRxnBounds(model2,'R_R00086',9,'b'); % Aumenta el mant ATP
model2=changeRxnBounds(model2,'R_Ex_Chorismate_e',0,'b');
model2=changeRxnBounds(model2,'R_Ex_TYR_e',0,'b');
model2=changeRxnBounds(model2,'R_Ex_TRP_e',-1.5,'b');
%%model1=changeRxnBounds(model1,'R_EX_Propionate_e',-5,'b');
model2=changeObjective(model2,'AIA_extracellular');

solution2=optimizeCbModel(model2)
fluxData=[solution2.v];
nonzeroflag=1;
exflag=1;
printFluxVector (model2, fluxData,nonzeroflag, exflag);

%% 

%CASE 3 Kinetics Bioreactor 3 /Propionate as Source of C/
%Stationary phase of growth/ 
%Maximize Mu_ Biomass with qs propionate

%model1=changeRxnBounds(model1,'R_bio00006', 0.16,'b');
model3=changeRxnBounds(model,'R_Ex_Glc_e',0,'b');
model3=changeRxnBounds(model3,'R_Ex_TYR_e',0,'b');
model3=changeRxnBounds(model3,'R_Ex_Chorismate_e',0,'b');
%%model1=changeRxnBounds(model1,'R_Ex_TRP_e',-1,'b');
model3=changeRxnBounds(model3,'R_Ex_Propionate_e',-2.85,'b');
%model1=changeObjective(model1,'AIA_extracellular');

solution3=optimizeCbModel(model3)
fluxData=[solution3.v];
nonzeroflag=1;
exflag=1;
printFluxVector (model3, fluxData,nonzeroflag, exflag);

%% CASE 4 Kinetics Bioreactor 3 /Propionate as Source of C/
% Stationary phase of growth/  
% Maximizing AIA with qs, mu, and qtrp as experimental constraints

model4=changeRxnBounds(model,'R_bio00006', 0.06,'b');
model4=changeRxnBounds(model4,'R_Ex_Glc_e',0,'b');
model4=changeRxnBounds(model4,'R_Ex_Chorismate_e',0,'b');
model4=changeRxnBounds(model4,'R_Ex_TYR_e',0,'b');
model4=changeRxnBounds(model4,'R_Ex_TRP_e',-1.8,'b');
model4=changeRxnBounds(model4,'R_Ex_Propionate_e',-2.85,'b');
model4=changeObjective(model4,'AIA_extracellular');

solution4=optimizeCbModel(model4)
fluxData=[solution4.v];
nonzeroflag=1;
exflag=1;
printFluxVector (model4, fluxData,nonzeroflag, exflag);